@@ -53,7 +53,7 @@ void FreeBusyGanttProxyModelTest::testModelValidity()
 
     const QDateTime dt1(QDate(2010, 8, 24), QTime(7, 0, 0), Qt::UTC);
     const QDateTime dt2(QDate(2010, 8, 24), QTime(16, 0, 0), Qt::UTC);
-    KCalCore::Attendee::Ptr a1(new KCalCore::Attendee(QStringLiteral("fred"), QStringLiteral("fred@example.com")));
+    KCalCore::Attendee a1(QStringLiteral("fred"), QStringLiteral("fred@example.com"));
     KCalCore::FreeBusy::Ptr fb1(new KCalCore::FreeBusy());
 
     fb1->addPeriod(dt1, KCalCore::Duration(60 * 60));
@@ -64,7 +64,7 @@ void FreeBusyGanttProxyModelTest::testModelValidity()
 
     const QDateTime dt3(QDate(2010, 8, 25), QTime(7, 0, 0), Qt::UTC);
     const QDateTime dt4(QDate(2010, 8, 25), QTime(16, 0, 0), Qt::UTC);
-    KCalCore::Attendee::Ptr a2(new KCalCore::Attendee(QStringLiteral("joe"), QStringLiteral("joe@example.com")));
+    KCalCore::Attendee a2(QStringLiteral("joe"), QStringLiteral("joe@example.com"));
     KCalCore::FreeBusy::Ptr fb2(new KCalCore::FreeBusy());
 
     fb2->addPeriod(dt3, KCalCore::Duration(60 * 60));
@@ -87,20 +87,20 @@ void FreeBusyGanttProxyModelTest::testModelValidity()
 
     QModelIndex source_parent0 = fbModel->index(0, 0);
     QCOMPARE(parent0.data(), source_parent0.data());
-    QCOMPARE(parent0.data(KGantt::ItemTypeRole).toInt(), (int) KGantt::TypeMulti);
+    QCOMPARE(parent0.data(KGantt::ItemTypeRole).toInt(), (int)KGantt::TypeMulti);
 
     QModelIndex source_parent1 = fbModel->index(1, 0);
     QCOMPARE(parent1.data(), source_parent1.data());
-    QCOMPARE(parent1.data(KGantt::ItemTypeRole).toInt(), (int) KGantt::TypeMulti);
+    QCOMPARE(parent1.data(KGantt::ItemTypeRole).toInt(), (int)KGantt::TypeMulti);
 
     QModelIndex child0_0 = ganttModel->index(0, 0, parent0);
     QModelIndex child0_1 = ganttModel->index(1, 0, parent0);
     QVERIFY(child0_0.isValid());
     QVERIFY(child0_1.isValid());
 
-    QCOMPARE(child0_0.data(KGantt::ItemTypeRole).toInt(), (int) KGantt::TypeTask);
+    QCOMPARE(child0_0.data(KGantt::ItemTypeRole).toInt(), (int)KGantt::TypeTask);
     QCOMPARE(child0_0.data(KGantt::StartTimeRole).toDateTime(), dt1);
-    QCOMPARE(child0_1.data(KGantt::ItemTypeRole).toInt(), (int) KGantt::TypeTask);
+    QCOMPARE(child0_1.data(KGantt::ItemTypeRole).toInt(), (int)KGantt::TypeTask);
     QCOMPARE(child0_1.data(KGantt::StartTimeRole).toDateTime(), dt2);
 
     QModelIndex child1_0 = ganttModel->index(0, 0, parent1);
@@ -108,8 +108,8 @@ void FreeBusyGanttProxyModelTest::testModelValidity()
     QVERIFY(child1_0.isValid());
     QVERIFY(child1_1.isValid());
 
-    QCOMPARE(child1_0.data(KGantt::ItemTypeRole).toInt(), (int) KGantt::TypeTask);
+    QCOMPARE(child1_0.data(KGantt::ItemTypeRole).toInt(), (int)KGantt::TypeTask);
     QCOMPARE(child1_0.data(KGantt::StartTimeRole).toDateTime(), dt3);
-    QCOMPARE(child1_1.data(KGantt::ItemTypeRole).toInt(), (int) KGantt::TypeTask);
+    QCOMPARE(child1_1.data(KGantt::ItemTypeRole).toInt(), (int)KGantt::TypeTask);
     QCOMPARE(child1_1.data(KGantt::StartTimeRole).toDateTime(), dt4);
 }
