@@ -31,12 +31,16 @@
 using namespace IncidenceEditorNG;
 
 AlarmDialog::AlarmDialog(KCalCore::Incidence::IncidenceType incidenceType, QWidget *parent)
-    : QDialog(parent),  mUi(new Ui::AlarmDialog), mIncidenceType(incidenceType),
-      mAllowBeginReminders(true), mAllowEndReminders(true)
+    : QDialog(parent)
+    , mUi(new Ui::AlarmDialog)
+    , mIncidenceType(incidenceType)
+    , mAllowBeginReminders(true)
+    , mAllowEndReminders(true)
 {
     setWindowTitle(i18n("Create a new reminder"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(
+        QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -57,6 +61,7 @@ AlarmDialog::AlarmDialog(KCalCore::Incidence::IncidenceType incidenceType, QWidg
     }
 
     mUi->mOffsetUnit->setCurrentIndex(defaultReminderUnits);
+    mUi->mSoundFile->setMimeTypeFilters({QStringLiteral("audio/x-wav"), QStringLiteral("audio/x-mp3"), QStringLiteral("application/ogg")});
 
     if (IncidenceEditorNG::EditorConfig::instance()->defaultAudioFileReminders()) {
         mUi->mSoundFile->setUrl(IncidenceEditorNG::EditorConfig::instance()->audioFilePath());
@@ -132,14 +137,16 @@ void AlarmDialog::load(const KCalCore::Alarm::Ptr &alarm)
         mUi->mAppArguments->setText(alarm->programArguments());
         id = 2;
         break;
-    case KCalCore::Alarm::Email: {
+    case KCalCore::Alarm::Email:
+    {
         mUi->mTypeCombo->setCurrentIndex(3);
         KCalCore::Person::List addresses = alarm->mailAddresses();
         QStringList add;
         add.reserve(addresses.count());
+        const KCalCore::Person::List::ConstIterator end(addresses.constEnd());
         for (KCalCore::Person::List::ConstIterator it = addresses.constBegin();
-                it != addresses.constEnd(); ++it) {
-            add << (*it)->fullName();
+             it != end; ++it) {
+            add << (*it).fullName();
         }
         mUi->mEmailAddress->setText(add.join(QStringLiteral(", ")));
         mUi->mEmailText->setPlainText(alarm->mailText());
@@ -155,8 +162,8 @@ void AlarmDialog::load(const KCalCore::Alarm::Ptr &alarm)
     }
 
     mUi->mTypeStack->setCurrentIndex(id);
-    if (alarm->audioFile().isEmpty() &&
-            IncidenceEditorNG::EditorConfig::instance()->defaultAudioFileReminders()) {
+    if (alarm->audioFile().isEmpty()
+        && IncidenceEditorNG::EditorConfig::instance()->defaultAudioFileReminders()) {
         mUi->mSoundFile->setUrl(IncidenceEditorNG::EditorConfig::instance()->audioFilePath());
     }
 }
