@@ -122,7 +122,7 @@ public:
 
 Q_SIGNALS:
     void changed();
-    void changed(const KCalCore::Attendee::Ptr &oldAttendee, const KCalCore::Attendee::Ptr &newAttendee);
+    void changed(const KCalCore::Attendee &oldAttendee, const KCalCore::Attendee &newAttendee);
     void editingFinished(KPIM::MultiplyingLine *);
 
 private:
