@@ -55,7 +55,7 @@ public:
         Tentative
     };
 
-    explicit AttendeeTableModel(const KCalCore::Attendee::List &resources, QObject *parent = nullptr);
+    explicit AttendeeTableModel(QObject *parent = nullptr);
 
     Q_REQUIRED_RESULT int rowCount(const QModelIndex &parent = QModelIndex()) const override;
     Q_REQUIRED_RESULT int columnCount(const QModelIndex &parent = QModelIndex()) const override;
@@ -68,7 +68,7 @@ public:
     Q_REQUIRED_RESULT bool insertRows(int position, int rows, const QModelIndex &index = QModelIndex()) override;
     Q_REQUIRED_RESULT bool removeRows(int position, int rows, const QModelIndex &index = QModelIndex()) override;
 
-    Q_REQUIRED_RESULT bool insertAttendee(int position, const KCalCore::Attendee::Ptr &attendee);
+    Q_REQUIRED_RESULT bool insertAttendee(int position, const KCalCore::Attendee &attendee);
 
     void setAttendees(const KCalCore::Attendee::List &resources);
     Q_REQUIRED_RESULT KCalCore::Attendee::List attendees() const;
@@ -82,7 +82,7 @@ private:
     void addEmptyAttendee();
 
     KCalCore::Attendee::List mAttendeeList;
-    QMap<KCalCore::Attendee::Ptr, AvailableStatus> mAttendeeAvailable;
+    std::vector<AvailableStatus> mAttendeeAvailable;
     bool mKeepEmpty;
     bool mRemoveEmptyLines;
 };
