@@ -59,10 +59,7 @@ IncidenceAttendee::IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTim
     , mRoleDelegate(new AttendeeComboBoxDelegate(this))
     , mResponseDelegate(new AttendeeComboBoxDelegate(this))
 {
-    KCalCore::Attendee::List attendees;
-    KCalCore::Attendee::Ptr attendee(new KCalCore::Attendee(QLatin1String(""), QLatin1String("")));
-    attendees.append(attendee);
-    mDataModel = new AttendeeTableModel(attendees, this);
+    mDataModel = new AttendeeTableModel(this);
     mDataModel->setKeepEmpty(true);
     mDataModel->setRemoveEmptyLines(true);
     mRoleDelegate->addItem(QIcon::fromTheme(QStringLiteral(":/meeting-participant.png")),
@@ -127,10 +124,10 @@ IncidenceAttendee::IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTim
     connect(mUi->mSolveButton, &QPushButton::clicked, this,
             &IncidenceAttendee::slotSolveConflictPressed);
     /* Added as part of kolab/issue2297, which is currently under review
-    connect(mUi->mOrganizerCombo, QOverload<const QString &>::of(&QComboBox::activated),
+    connect(mUi->mOrganizerCombo, qOverload<const QString &>(&QComboBox::activated),
             this, &IncidenceAttendee::slotOrganizerChanged);
     */
-    connect(mUi->mOrganizerCombo, QOverload<int>::of(&QComboBox::currentIndexChanged),
+    connect(mUi->mOrganizerCombo, qOverload<int>(&QComboBox::currentIndexChanged),
             this, &IncidenceAttendee::checkDirtyStatus);
 
     connect(mDateTime, &IncidenceDateTime::startDateChanged, this,
@@ -194,16 +191,16 @@ void IncidenceAttendee::load(const KCalCore::Incidence::Ptr &incidence)
 {
     mLoadedIncidence = incidence;
 
-    if (iAmOrganizer() || incidence->organizer()->isEmpty()) {
+    if (iAmOrganizer() || incidence->organizer().isEmpty()) {
         mUi->mOrganizerStack->setCurrentIndex(0);
 
         int found = -1;
-        const QString fullOrganizer = incidence->organizer()->fullName();
-        const QString organizerEmail = incidence->organizer()->email();
+        const QString fullOrganizer = incidence->organizer().fullName();
+        const QString organizerEmail = incidence->organizer().email();
         for (int i = 0; i < mUi->mOrganizerCombo->count(); ++i) {
-            KCalCore::Person::Ptr organizerCandidate
+            KCalCore::Person organizerCandidate
                 = KCalCore::Person::fromFullName(mUi->mOrganizerCombo->itemText(i));
-            if (organizerCandidate->email() == organizerEmail) {
+            if (organizerCandidate.email() == organizerEmail) {
                 found = i;
                 mUi->mOrganizerCombo->setCurrentIndex(i);
                 break;
@@ -217,15 +214,15 @@ void IncidenceAttendee::load(const KCalCore::Incidence::Ptr &incidence)
         mUi->mOrganizerLabel->setVisible(false);
     } else { // someone else is the organizer
         mUi->mOrganizerStack->setCurrentIndex(1);
-        mUi->mOrganizerLabel->setText(incidence->organizer()->fullName());
+        mUi->mOrganizerLabel->setText(incidence->organizer().fullName());
         mUi->mOrganizerLabel->setVisible(true);
     }
 
     KCalCore::Attendee::List attendees;
     const KCalCore::Attendee::List incidenceAttendees = incidence->attendees();
     attendees.reserve(incidenceAttendees.count());
-    for (const KCalCore::Attendee::Ptr &a : incidenceAttendees) {
-        attendees << KCalCore::Attendee::Ptr(new KCalCore::Attendee(*a));
+    for (const KCalCore::Attendee &a : incidenceAttendees) {
+        attendees << KCalCore::Attendee(a);
     }
 
     mDataModel->setAttendees(attendees);
@@ -241,20 +238,18 @@ void IncidenceAttendee::save(const KCalCore::Incidence::Ptr &incidence)
     incidence->clearAttendees();
     const KCalCore::Attendee::List attendees = mDataModel->attendees();
 
-    for (const KCalCore::Attendee::Ptr &attendee : attendees) {
-        Q_ASSERT(attendee);
-
+    for (const KCalCore::Attendee &attendee : attendees) {
         bool skip = false;
-        if (attendee->fullName().isEmpty()) {
+        if (attendee.fullName().isEmpty()) {
             continue;
         }
-        if (KEmailAddress::isValidAddress(attendee->email())) {
+        if (KEmailAddress::isValidAddress(attendee.email())) {
             if (KMessageBox::warningYesNo(
                     nullptr,
                     i18nc("@info",
                           "%1 does not look like a valid email address. "
                           "Are you sure you want to invite this participant?",
-                          attendee->email()),
+                          attendee.email()),
                     i18nc("@title:window", "Invalid Email Address")) != KMessageBox::Yes) {
                 skip = true;
             }
@@ -282,12 +277,12 @@ bool IncidenceAttendee::isDirty() const
         KCalCore::Event tmp;
         tmp.setOrganizer(mUi->mOrganizerCombo->currentText());
 
-        if (mLoadedIncidence->organizer()->email() != tmp.organizer()->email()) {
+        if (mLoadedIncidence->organizer().email() != tmp.organizer().email()) {
             qCDebug(INCIDENCEEDITOR_LOG) << "Organizer changed. Old was "
-                                         << mLoadedIncidence->organizer()->name()
-                                         << mLoadedIncidence->organizer()->email() << "; new is "
-                                         << tmp.organizer()->name()
-                                         << tmp.organizer()->email();
+                                         << mLoadedIncidence->organizer().name()
+                                         << mLoadedIncidence->organizer().email() << "; new is "
+                                         << tmp.organizer().name()
+                                         << tmp.organizer().email();
             return true;
         }
     }
@@ -296,8 +291,8 @@ bool IncidenceAttendee::isDirty() const
     KCalCore::Attendee::List newList;
 
     const auto lstAttendees = mDataModel->attendees();
-    for (const KCalCore::Attendee::Ptr &attendee : lstAttendees) {
-        if (!attendee->fullName().isEmpty()) {
+    for (const KCalCore::Attendee &attendee : lstAttendees) {
+        if (!attendee.fullName().isEmpty()) {
             newList.append(attendee);
         }
     }
@@ -310,10 +305,10 @@ bool IncidenceAttendee::isDirty() const
 
     // Okay, again not the most efficient algorithm, but I'm assuming that in the
     // bulk of the use cases, the number of attendees is not much higher than 10 or so.
-    for (const KCalCore::Attendee::Ptr &attendee : originalList) {
+    for (const KCalCore::Attendee &attendee : originalList) {
         bool found = false;
         for (int i = 0; i < newList.count(); ++i) {
-            if (*(newList[i]) == *attendee) {
+            if (newList[i] == attendee) {
                 newList.remove(i);
                 found = true;
                 break;
@@ -369,19 +364,19 @@ void IncidenceAttendee::fillOrganizerCombo()
     mUi->mOrganizerCombo->addItems(uniqueList);
 }
 
-void IncidenceAttendee::checkIfExpansionIsNeeded(const KCalCore::Attendee::Ptr &attendee)
+void IncidenceAttendee::checkIfExpansionIsNeeded(const KCalCore::Attendee &attendee)
 {
-    QString fullname = attendee->fullName();
+    QString fullname = attendee.fullName();
 
     // stop old job
-    KJob *oldJob = mMightBeGroupJobs.key(attendee);
+    KJob *oldJob = mMightBeGroupJobs.key(attendee.uid());
     if (oldJob != nullptr) {
         disconnect(oldJob);
         oldJob->deleteLater();
         mMightBeGroupJobs.remove(oldJob);
     }
 
-    mGroupList.remove(attendee);
+    mGroupList.remove(attendee.uid());
 
     if (!fullname.isEmpty()) {
         Akonadi::ContactGroupSearchJob *job = new Akonadi::ContactGroupSearchJob();
@@ -389,7 +384,7 @@ void IncidenceAttendee::checkIfExpansionIsNeeded(const KCalCore::Attendee::Ptr &
         connect(job, &Akonadi::ContactGroupSearchJob::result, this,
                 &IncidenceAttendee::groupSearchResult);
 
-        mMightBeGroupJobs.insert(job, attendee);
+        mMightBeGroupJobs.insert(job, attendee.uid());
     }
 }
 
@@ -399,7 +394,7 @@ void IncidenceAttendee::groupSearchResult(KJob *job)
     Q_ASSERT(searchJob);
 
     Q_ASSERT(mMightBeGroupJobs.contains(job));
-    KCalCore::Attendee::Ptr attendee = mMightBeGroupJobs.take(job);
+    const auto uid = mMightBeGroupJobs.take(job);
 
     const KContacts::ContactGroup::List contactGroups = searchJob->contactGroups();
     if (contactGroups.isEmpty()) {
@@ -410,11 +405,11 @@ void IncidenceAttendee::groupSearchResult(KJob *job)
     // TODO: Give the user the possibility to choose a group when there is more than one?!
     KContacts::ContactGroup group = contactGroups.first();
 
-    int row = dataModel()->attendees().indexOf(attendee);
+    const int row = rowOfAttendee(uid);
     QModelIndex index = dataModel()->index(row, AttendeeTableModel::CuType);
     dataModel()->setData(index, KCalCore::Attendee::Group);
 
-    mGroupList.insert(attendee, group);
+    mGroupList.insert(uid, group);
     updateGroupExpand();
 }
 
@@ -426,13 +421,10 @@ void IncidenceAttendee::updateGroupExpand()
 void IncidenceAttendee::slotGroupSubstitutionPressed()
 {
     for (auto it = mGroupList.cbegin(), end = mGroupList.cend(); it != end; ++it) {
-        const KCalCore::Attendee::Ptr attendee = it.key();
-        Akonadi::ContactGroupExpandJob *expandJob = new Akonadi::ContactGroupExpandJob(mGroupList.value(
-                                                                                           attendee),
-                                                                                       this);
+        Akonadi::ContactGroupExpandJob *expandJob = new Akonadi::ContactGroupExpandJob(it.value(), this);
         connect(expandJob, &Akonadi::ContactGroupExpandJob::result, this,
                 &IncidenceAttendee::expandResult);
-        mExpandGroupJobs.insert(expandJob, attendee);
+        mExpandGroupJobs.insert(expandJob, it.key());
         expandJob->start();
     }
 }
@@ -442,9 +434,10 @@ void IncidenceAttendee::expandResult(KJob *job)
     Akonadi::ContactGroupExpandJob *expandJob = qobject_cast<Akonadi::ContactGroupExpandJob *>(job);
     Q_ASSERT(expandJob);
     Q_ASSERT(mExpandGroupJobs.contains(job));
-    KCalCore::Attendee::Ptr attendee = mExpandGroupJobs.take(job);
-    int row = dataModel()->attendees().indexOf(attendee);
-    const QString currentEmail = attendee->email();
+    const auto uid = mExpandGroupJobs.take(job);
+    const int row = rowOfAttendee(uid);
+    const auto attendee = dataModel()->attendees().at(row);
+    const QString currentEmail = attendee.email();
     const KContacts::Addressee::List groupMembers = expandJob->contacts();
     bool wasACorrectEmail = false;
     for (const KContacts::Addressee &member : groupMembers) {
@@ -457,12 +450,11 @@ void IncidenceAttendee::expandResult(KJob *job)
     if (!wasACorrectEmail) {
         dataModel()->removeRow(row);
         for (const KContacts::Addressee &member : groupMembers) {
-            KCalCore::Attendee::Ptr newAt(new KCalCore::Attendee(
-                                              member.realName(), member.preferredEmail(),
-                                              attendee->RSVP(),
-                                              attendee->status(),
-                                              attendee->role(),
-                                              member.uid()));
+            KCalCore::Attendee newAt(member.realName(), member.preferredEmail(),
+                                              attendee.RSVP(),
+                                              attendee.status(),
+                                              attendee.role(),
+                                              member.uid());
             dataModel()->insertAttendee(row, newAt);
         }
     }
@@ -486,16 +478,14 @@ void IncidenceAttendee::slotSelectAddresses()
                 bool rsvp = true;
 
                 int pos = 0;
-                KCalCore::Attendee::Ptr newAt(new KCalCore::Attendee(
-                                                  selection.name(),
+                KCalCore::Attendee newAt(selection.name(),
                                                   selection.email(),
                                                   rsvp,
                                                   partStat,
-                                                  KCalCore::Attendee::ReqParticipant
-                                                  ));
+                                                  KCalCore::Attendee::ReqParticipant);
                 dataModel()->insertAttendee(pos, newAt);
 
-                mExpandGroupJobs.insert(job, newAt);
+                mExpandGroupJobs.insert(job, newAt.uid());
                 job->start();
             } else {
                 KContacts::Addressee contact;
@@ -535,9 +525,9 @@ void IncidenceAttendee::slotConflictResolverAttendeeChanged(const QModelIndex &t
         && AttendeeTableModel::FullName >= topLeft.column()) {
         for (int i = topLeft.row(); i <= bottomRight.row(); ++i) {
             QModelIndex email = dataModel()->index(i, AttendeeTableModel::Email);
-            KCalCore::Attendee::Ptr attendee = dataModel()->data(email,
+            KCalCore::Attendee attendee = dataModel()->data(email,
                                                                  AttendeeTableModel::AttendeeRole).
-                                               value<KCalCore::Attendee::Ptr>();
+                                               value<KCalCore::Attendee>();
             if (mConflictResolver->containsAttendee(attendee)) {
                 mConflictResolver->removeAttendee(attendee);
             }
@@ -556,7 +546,7 @@ void IncidenceAttendee::slotConflictResolverAttendeeAdded(const QModelIndex &ind
         if (!dataModel()->data(email).toString().isEmpty()) {
             mConflictResolver->insertAttendee(dataModel()->data(email,
                                                                 AttendeeTableModel::AttendeeRole).value<
-                                                  KCalCore::Attendee::Ptr>());
+                                                  KCalCore::Attendee>());
         }
     }
     checkDirtyStatus();
@@ -569,7 +559,7 @@ void IncidenceAttendee::slotConflictResolverAttendeeRemoved(const QModelIndex &i
         if (!dataModel()->data(email).toString().isEmpty()) {
             mConflictResolver->removeAttendee(dataModel()->data(email,
                                                                 AttendeeTableModel::AttendeeRole).value<
-                                                  KCalCore::Attendee::Ptr>());
+                                                  KCalCore::Attendee>());
         }
     }
     checkDirtyStatus();
@@ -579,8 +569,8 @@ void IncidenceAttendee::slotConflictResolverLayoutChanged()
 {
     const KCalCore::Attendee::List attendees = mDataModel->attendees();
     mConflictResolver->clearAttendees();
-    for (const KCalCore::Attendee::Ptr &attendee : attendees) {
-        if (!attendee->email().isEmpty()) {
+    for (const KCalCore::Attendee &attendee : attendees) {
+        if (!attendee.email().isEmpty()) {
             mConflictResolver->insertAttendee(attendee);
         }
     }
@@ -596,11 +586,11 @@ void IncidenceAttendee::slotFreeBusyAdded(const QModelIndex &parent, int first,
     QAbstractItemModel *model = mConflictResolver->model();
     for (int i = first; i <= last; ++i) {
         QModelIndex index = model->index(i, 0, parent);
-        const KCalCore::Attendee::Ptr &attendee
-            = model->data(index, CalendarSupport::FreeBusyItemModel::AttendeeRole).value<KCalCore::Attendee::Ptr>();
+        const KCalCore::Attendee &attendee
+            = model->data(index, CalendarSupport::FreeBusyItemModel::AttendeeRole).value<KCalCore::Attendee>();
         const KCalCore::FreeBusy::Ptr &fb
             = model->data(index, CalendarSupport::FreeBusyItemModel::FreeBusyRole).value<KCalCore::FreeBusy::Ptr>();
-        if (attendee) {
+        if (!attendee.isNull()) {
             updateFBStatus(attendee, fb);
         }
     }
@@ -615,11 +605,11 @@ void IncidenceAttendee::slotFreeBusyChanged(const QModelIndex &topLeft, const QM
     QAbstractItemModel *model = mConflictResolver->model();
     for (int i = topLeft.row(); i <= bottomRight.row(); ++i) {
         QModelIndex index = model->index(i, 0);
-        const KCalCore::Attendee::Ptr &attendee
-            = model->data(index, CalendarSupport::FreeBusyItemModel::AttendeeRole).value<KCalCore::Attendee::Ptr>();
+        const KCalCore::Attendee &attendee
+            = model->data(index, CalendarSupport::FreeBusyItemModel::AttendeeRole).value<KCalCore::Attendee>();
         const KCalCore::FreeBusy::Ptr &fb
             = model->data(index, CalendarSupport::FreeBusyItemModel::FreeBusyRole).value<KCalCore::FreeBusy::Ptr>();
-        if (attendee) {
+        if (!attendee.isNull()) {
             updateFBStatus(attendee, fb);
         }
     }
@@ -630,17 +620,17 @@ void IncidenceAttendee::updateFBStatus()
     QAbstractItemModel *model = mConflictResolver->model();
     for (int i = 0; i < model->rowCount(); ++i) {
         QModelIndex index = model->index(i, 0);
-        const KCalCore::Attendee::Ptr &attendee
-            = model->data(index, CalendarSupport::FreeBusyItemModel::AttendeeRole).value<KCalCore::Attendee::Ptr>();
+        const KCalCore::Attendee &attendee
+            = model->data(index, CalendarSupport::FreeBusyItemModel::AttendeeRole).value<KCalCore::Attendee>();
         const KCalCore::FreeBusy::Ptr &fb
             = model->data(index, CalendarSupport::FreeBusyItemModel::FreeBusyRole).value<KCalCore::FreeBusy::Ptr>();
-        if (attendee) {
+        if (!attendee.isNull()) {
             updateFBStatus(attendee, fb);
         }
     }
 }
 
-void IncidenceAttendee::updateFBStatus(const KCalCore::Attendee::Ptr &attendee, const KCalCore::FreeBusy::Ptr &fb)
+void IncidenceAttendee::updateFBStatus(const KCalCore::Attendee &attendee, const KCalCore::FreeBusy::Ptr &fb)
 {
     KCalCore::Attendee::List attendees = mDataModel->attendees();
     QDateTime startTime = mDateTime->currentStartDateTime();
@@ -655,7 +645,7 @@ void IncidenceAttendee::updateFBStatus(const KCalCore::Attendee::Ptr &attendee,
                 // periods starting in the time of incidence (s >= startTime && s <= endTime)
                 if (((*it).start() < startTime && (*it).end() > startTime)
                     || ((*it).start() >= startTime && (*it).start() <= endTime)) {
-                    switch (attendee->status()) {
+                    switch (attendee.status()) {
                     case KCalCore::Attendee::Accepted:
                         dataModel()->setData(attendeeIndex, AttendeeTableModel::Accepted);
                         return;
@@ -697,9 +687,9 @@ void IncidenceAttendee::slotGroupSubstitutionAttendeeChanged(const QModelIndex &
         && AttendeeTableModel::FullName >= topLeft.column()) {
         for (int i = topLeft.row(); i <= bottomRight.row(); ++i) {
             QModelIndex email = dataModel()->index(i, AttendeeTableModel::Email);
-            KCalCore::Attendee::Ptr attendee = dataModel()->data(email,
+            KCalCore::Attendee attendee = dataModel()->data(email,
                                                                  AttendeeTableModel::AttendeeRole).
-                                               value<KCalCore::Attendee::Ptr>();
+                                               value<KCalCore::Attendee>();
             checkIfExpansionIsNeeded(attendee);
         }
     }
@@ -711,9 +701,9 @@ void IncidenceAttendee::slotGroupSubstitutionAttendeeAdded(const QModelIndex &in
     Q_UNUSED(index);
     for (int i = first; i <= last; ++i) {
         QModelIndex email = dataModel()->index(i, AttendeeTableModel::Email);
-        KCalCore::Attendee::Ptr attendee
+        KCalCore::Attendee attendee
             = dataModel()->data(email,
-                                AttendeeTableModel::AttendeeRole).value<KCalCore::Attendee::Ptr>();
+                                AttendeeTableModel::AttendeeRole).value<KCalCore::Attendee>();
         checkIfExpansionIsNeeded(attendee);
     }
     updateGroupExpand();
@@ -724,22 +714,22 @@ void IncidenceAttendee::slotGroupSubstitutionAttendeeRemoved(const QModelIndex &
     Q_UNUSED(index);
     for (int i = first; i <= last; ++i) {
         QModelIndex email = dataModel()->index(i, AttendeeTableModel::Email);
-        KCalCore::Attendee::Ptr attendee
+        KCalCore::Attendee attendee
             = dataModel()->data(email,
-                                AttendeeTableModel::AttendeeRole).value<KCalCore::Attendee::Ptr>();
-        KJob *job = mMightBeGroupJobs.key(attendee);
+                                AttendeeTableModel::AttendeeRole).value<KCalCore::Attendee>();
+        KJob *job = mMightBeGroupJobs.key(attendee.uid());
         if (job) {
             disconnect(job);
             job->deleteLater();
             mMightBeGroupJobs.remove(job);
         }
-        job = mExpandGroupJobs.key(attendee);
+        job = mExpandGroupJobs.key(attendee.uid());
         if (job) {
             disconnect(job);
             job->deleteLater();
             mExpandGroupJobs.remove(job);
         }
-        mGroupList.remove(attendee);
+        mGroupList.remove(attendee.uid());
     }
     updateGroupExpand();
 }
@@ -769,9 +759,9 @@ void IncidenceAttendee::slotGroupSubstitutionLayoutChanged()
         QModelIndex index = model->index(i, AttendeeTableModel::FullName);
         if (!model->data(index).toString().isEmpty()) {
             QModelIndex email = dataModel()->index(i, AttendeeTableModel::Email);
-            KCalCore::Attendee::Ptr attendee = dataModel()->data(email,
+            KCalCore::Attendee attendee = dataModel()->data(email,
                                                                  AttendeeTableModel::AttendeeRole).
-                                               value<KCalCore::Attendee::Ptr>();
+                                               value<KCalCore::Attendee>();
             checkIfExpansionIsNeeded(attendee);
         }
     }
@@ -783,7 +773,7 @@ bool IncidenceAttendee::iAmOrganizer() const
 {
     if (mLoadedIncidence) {
         const IncidenceEditorNG::EditorConfig *config = IncidenceEditorNG::EditorConfig::instance();
-        return config->thatIsMe(mLoadedIncidence->organizer()->email());
+        return config->thatIsMe(mLoadedIncidence->organizer().email());
     }
 
     return true;
@@ -802,11 +792,11 @@ void IncidenceAttendee::insertAttendeeFromAddressee(const KContacts::Addressee &
         partStat = KCalCore::Attendee::Accepted;
         rsvp = false;
     }
-    KCalCore::Attendee::Ptr newAt(new KCalCore::Attendee(a.realName(), a.preferredEmail(),
+    KCalCore::Attendee newAt(a.realName(), a.preferredEmail(),
                                                          rsvp,
                                                          partStat,
                                                          KCalCore::Attendee::ReqParticipant,
-                                                         a.uid()));
+                                                         a.uid());
     if (pos < 0) {
         pos = dataModel()->rowCount() - 1;
     }
@@ -880,9 +870,8 @@ void IncidenceAttendee::slotOrganizerChanged(const QString &newOrganizer)
             KCalCore::Attendee::PartStat status = iAmOrganizer() ? KCalCore::Attendee::Accepted
                                                   : KCalCore::Attendee::NeedsAction;
 
-            KCalCore::Attendee::Ptr newAt(
-                new KCalCore::Attendee(name, email, rsvp, status,
-                                       KCalCore::Attendee::ReqParticipant));
+            KCalCore::Attendee newAt(name, email, rsvp, status,
+                                       KCalCore::Attendee::ReqParticipant);
 
             mDataModel->insertAttendee(mDataModel->rowCount(), newAt);
         }
@@ -987,12 +976,12 @@ void IncidenceAttendee::setActions(KCalCore::Incidence::IncidenceType actions)
 void IncidenceAttendee::printDebugInfo() const
 {
     qCDebug(INCIDENCEEDITOR_LOG) << "I'm organizer   : " << iAmOrganizer();
-    qCDebug(INCIDENCEEDITOR_LOG) << "Loaded organizer: " << mLoadedIncidence->organizer()->email();
+    qCDebug(INCIDENCEEDITOR_LOG) << "Loaded organizer: " << mLoadedIncidence->organizer().email();
 
     if (iAmOrganizer()) {
         KCalCore::Event tmp;
         tmp.setOrganizer(mUi->mOrganizerCombo->currentText());
-        qCDebug(INCIDENCEEDITOR_LOG) << "Organizer combo: " << tmp.organizer()->email();
+        qCDebug(INCIDENCEEDITOR_LOG) << "Organizer combo: " << tmp.organizer().email();
     }
 
     const KCalCore::Attendee::List originalList = mLoadedIncidence->attendees();
@@ -1000,15 +989,15 @@ void IncidenceAttendee::printDebugInfo() const
     qCDebug(INCIDENCEEDITOR_LOG) << "List sizes: " << originalList.count() << newList.count();
 
     const auto lstAttendees = mDataModel->attendees();
-    for (const KCalCore::Attendee::Ptr &attendee : lstAttendees) {
-        if (!attendee->fullName().isEmpty()) {
+    for (const KCalCore::Attendee &attendee : lstAttendees) {
+        if (!attendee.fullName().isEmpty()) {
             newList.append(attendee);
         }
     }
 
     // Okay, again not the most efficient algorithm, but I'm assuming that in the
     // bulk of the use cases, the number of attendees is not much higher than 10 or so.
-    for (const KCalCore::Attendee::Ptr &attendee : originalList) {
+    for (const KCalCore::Attendee &attendee : originalList) {
         bool found = false;
         for (int i = 0; i < newList.count(); ++i) {
             if (newList[i] == attendee) {
@@ -1019,30 +1008,39 @@ void IncidenceAttendee::printDebugInfo() const
         }
 
         if (!found) {
-            qCDebug(INCIDENCEEDITOR_LOG) << "Attendee not found: " << attendee->email()
-                                         << attendee->name()
-                                         << attendee->status()
-                                         << attendee->RSVP()
-                                         << attendee->role()
-                                         << attendee->uid()
-                                         << attendee->cuType()
-                                         << attendee->delegate()
-                                         << attendee->delegator()
+            qCDebug(INCIDENCEEDITOR_LOG) << "Attendee not found: " << attendee.email()
+                                         << attendee.name()
+                                         << attendee.status()
+                                         << attendee.RSVP()
+                                         << attendee.role()
+                                         << attendee.uid()
+                                         << attendee.cuType()
+                                         << attendee.delegate()
+                                         << attendee.delegator()
                                          << "; we have:";
             for (int i = 0; i < newList.count(); ++i) {
-                KCalCore::Attendee::Ptr attendee = newList[i];
-                qCDebug(INCIDENCEEDITOR_LOG) << "Attendee: " << attendee->email()
-                                             << attendee->name()
-                                             << attendee->status()
-                                             << attendee->RSVP()
-                                             << attendee->role()
-                                             << attendee->uid()
-                                             << attendee->cuType()
-                                             << attendee->delegate()
-                                             << attendee->delegator();
+                KCalCore::Attendee attendee = newList[i];
+                qCDebug(INCIDENCEEDITOR_LOG) << "Attendee: " << attendee.email()
+                                             << attendee.name()
+                                             << attendee.status()
+                                             << attendee.RSVP()
+                                             << attendee.role()
+                                             << attendee.uid()
+                                             << attendee.cuType()
+                                             << attendee.delegate()
+                                             << attendee.delegator();
             }
 
             return;
         }
     }
 }
+
+int IncidenceAttendee::rowOfAttendee(const QString &uid) const
+{
+    const auto attendees = dataModel()->attendees();
+    const auto it = std::find_if(attendees.begin(), attendees.end(), [uid](const KCalCore::Attendee &att) {
+        return att.uid() == uid;
+    });
+    return std::distance(attendees.begin(), it);
+}
