@@ -76,7 +76,7 @@ public Q_SLOTS:
 
 private Q_SLOTS:
     // cheks if row is a group,  that can/should be expanded
-    void checkIfExpansionIsNeeded(const KCalCore::Attendee::Ptr &attendee);
+    void checkIfExpansionIsNeeded(const KCalCore::Attendee &attendee);
 
     // results of the group search job
     void groupSearchResult(KJob *job);
@@ -100,7 +100,7 @@ private Q_SLOTS:
     void slotFreeBusyAdded(const QModelIndex &index, int first, int last);
     void slotFreeBusyChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight);
     void updateFBStatus();
-    void updateFBStatus(const KCalCore::Attendee::Ptr &attendee, const KCalCore::FreeBusy::Ptr &fb);
+    void updateFBStatus(const KCalCore::Attendee &attendee, const KCalCore::FreeBusy::Ptr &fb);
 
     void slotGroupSubstitutionAttendeeAdded(const QModelIndex &index, int first, int last);
     void slotGroupSubstitutionAttendeeRemoved(const QModelIndex &index, int first, int last);
@@ -126,6 +126,8 @@ private:
     void fillOrganizerCombo();
     void setActions(KCalCore::Incidence::IncidenceType actions);
 
+    int rowOfAttendee(const QString &uid) const;
+
     Ui::EventOrTodoDesktop *mUi = nullptr;
     QWidget *mParentWidget = nullptr;
     ConflictResolver *mConflictResolver = nullptr;
@@ -140,9 +142,10 @@ private:
     AttendeeComboBoxDelegate *mRoleDelegate = nullptr;
     AttendeeComboBoxDelegate *mResponseDelegate = nullptr;
 
-    QMap<KCalCore::Attendee::Ptr, KContacts::ContactGroup> mGroupList;
-    QMap<KJob *, KCalCore::Attendee::Ptr> mMightBeGroupJobs;
-    QMap<KJob *, KCalCore::Attendee::Ptr> mExpandGroupJobs;
+    // the QString is Attendee::uid here
+    QMap<QString, KContacts::ContactGroup> mGroupList;
+    QMap<KJob *, QString> mMightBeGroupJobs;
+    QMap<KJob *, QString> mExpandGroupJobs;
 };
 }
 
