@@ -57,7 +57,7 @@ class IncidenceDefaultsPrivate
 public:
     /// Members
     KCalCore::Attachment::List mAttachments;
-    QVector<KCalCore::Attendee::Ptr> mAttendees;
+    QVector<KCalCore::Attendee> mAttendees;
     QStringList mEmails;
     QString mGroupWareDomain;
     KCalCore::Incidence::Ptr mRelatedIncidence;
@@ -66,8 +66,8 @@ public:
     bool mCleanupTemporaryFiles;
 
     /// Methods
-    KCalCore::Person::Ptr organizerAsPerson() const;
-    KCalCore::Attendee::Ptr organizerAsAttendee(const KCalCore::Person::Ptr &organizer) const;
+    KCalCore::Person organizerAsPerson() const;
+    KCalCore::Attendee organizerAsAttendee(const KCalCore::Person &organizer) const;
 
     void todoDefaults(const KCalCore::Todo::Ptr &todo) const;
     void eventDefaults(const KCalCore::Event::Ptr &event) const;
@@ -75,13 +75,13 @@ public:
 };
 }
 
-KCalCore::Person::Ptr IncidenceDefaultsPrivate::organizerAsPerson() const
+KCalCore::Person IncidenceDefaultsPrivate::organizerAsPerson() const
 {
     const QString invalidEmail = IncidenceDefaults::invalidEmailAddress();
 
-    KCalCore::Person::Ptr organizer(new KCalCore::Person);
-    organizer->setName(i18nc("@label", "no (valid) identities found"));
-    organizer->setEmail(invalidEmail);
+    KCalCore::Person organizer;
+    organizer.setName(i18nc("@label", "no (valid) identities found"));
+    organizer.setEmail(invalidEmail);
 
     if (mEmails.isEmpty()) {
         // Don't bother any longer, either someone forget to call setFullEmails, or
@@ -97,14 +97,14 @@ KCalCore::Person::Ptr IncidenceDefaultsPrivate::organizerAsPerson() const
             QString email;
             const bool success = KEmailAddress::extractEmailAddressAndName(fullEmail, email, name);
             if (success && email.endsWith(mGroupWareDomain)) {
-                organizer->setName(name);
-                organizer->setEmail(email);
+                organizer.setName(name);
+                organizer.setEmail(email);
                 break;
             }
         }
     }
 
-    if (organizer->email() == invalidEmail) {
+    if (organizer.email() == invalidEmail) {
         // Either, no groupware was used, or we didn't find a groupware email address.
         // Now try to
         for (const QString &fullEmail : qAsConst(mEmails)) {
@@ -112,8 +112,8 @@ KCalCore::Person::Ptr IncidenceDefaultsPrivate::organizerAsPerson() const
             QString email;
             const bool success = KEmailAddress::extractEmailAddressAndName(fullEmail, email, name);
             if (success) {
-                organizer->setName(name);
-                organizer->setEmail(email);
+                organizer.setName(name);
+                organizer.setEmail(email);
                 break;
             }
         }
@@ -122,19 +122,18 @@ KCalCore::Person::Ptr IncidenceDefaultsPrivate::organizerAsPerson() const
     return organizer;
 }
 
-KCalCore::Attendee::Ptr IncidenceDefaultsPrivate::organizerAsAttendee(
-    const KCalCore::Person::Ptr &organizer) const
+KCalCore::Attendee IncidenceDefaultsPrivate::organizerAsAttendee(
+    const KCalCore::Person &organizer) const
 {
-    KCalCore::Attendee::Ptr organizerAsAttendee(new KCalCore::Attendee(QLatin1String(
-                                                                           ""), QLatin1String("")));
+    KCalCore::Attendee organizerAsAttendee;
     // Really, the appropriate values (even the fall back values) should come from
     // organizer. (See organizerAsPerson for more details).
-    organizerAsAttendee->setName(organizer->name());
-    organizerAsAttendee->setEmail(organizer->email());
+    organizerAsAttendee.setName(organizer.name());
+    organizerAsAttendee.setEmail(organizer.email());
     // NOTE: Don't set the status to None, this value is not supported by the attendee
     //       editor atm.
-    organizerAsAttendee->setStatus(KCalCore::Attendee::Accepted);
-    organizerAsAttendee->setRole(KCalCore::Attendee::ReqParticipant);
+    organizerAsAttendee.setStatus(KCalCore::Attendee::Accepted);
+    organizerAsAttendee.setRole(KCalCore::Attendee::ReqParticipant);
     return organizerAsAttendee;
 }
 
@@ -260,17 +259,15 @@ void IncidenceDefaults::setAttachments(const QStringList &attachments, const QSt
                 mimeType = attachmentMimetypes[ i ];
             }
 
-            KCalCore::Attachment::Ptr attachment;
+            KCalCore::Attachment attachment;
             if (inlineAttachment) {
                 auto job = KIO::storedGet(QUrl::fromUserInput(*it));
                 if (job->exec()) {
                     const QByteArray data = job->data();
-                    attachment
-                        = KCalCore::Attachment::Ptr(new KCalCore::Attachment(data.toBase64(),
-                                                                             mimeType));
+                    attachment = KCalCore::Attachment(data.toBase64(), mimeType);
 
                     if (i < attachmentLabels.count()) {
-                        attachment->setLabel(attachmentLabels[ i ]);
+                        attachment.setLabel(attachmentLabels[ i ]);
                     }
                 } else {
                     qCCritical(INCIDENCEEDITOR_LOG) << "Error downloading uri " << *it
@@ -284,23 +281,23 @@ void IncidenceDefaults::setAttachments(const QStringList &attachments, const QSt
                     }
                 }
             } else {
-                attachment = KCalCore::Attachment::Ptr(new KCalCore::Attachment(*it, mimeType));
+                attachment = KCalCore::Attachment(*it, mimeType);
                 if (i < attachmentLabels.count()) {
-                    attachment->setLabel(attachmentLabels[ i ]);
+                    attachment.setLabel(attachmentLabels[ i ]);
                 }
             }
 
-            if (attachment) {
-                if (attachment->label().isEmpty()) {
-                    if (attachment->isUri()) {
-                        attachment->setLabel(attachment->uri());
+            if (!attachment.isEmpty()) {
+                if (attachment.label().isEmpty()) {
+                    if (attachment.isUri()) {
+                        attachment.setLabel(attachment.uri());
                     } else {
-                        attachment->setLabel(
+                        attachment.setLabel(
                             i18nc("@label attachment contains binary data", "[Binary data]"));
                     }
                 }
                 d->mAttachments << attachment;
-                attachment->setShowInline(inlineAttachment);
+                attachment.setShowInline(inlineAttachment);
             }
         }
     }
@@ -314,8 +311,7 @@ void IncidenceDefaults::setAttendees(const QStringList &attendees)
     for (it = attendees.begin(); it != attendees.end(); ++it) {
         QString name, email;
         KContacts::Addressee::parseEmailAddress(*it, name, email);
-        d->mAttendees << KCalCore::Attendee::Ptr(
-            new KCalCore::Attendee(name, email, true, KCalCore::Attendee::NeedsAction));
+        d->mAttendees << KCalCore::Attendee(name, email, true, KCalCore::Attendee::NeedsAction);
     }
 }
 
@@ -374,13 +370,12 @@ void IncidenceDefaults::setDefaults(const KCalCore::Incidence::Ptr &incidence) c
     incidence->clearComments();
     incidence->clearContacts();
     incidence->clearRecurrence();
-    incidence->clearTempFiles();
 
-    const KCalCore::Person::Ptr organizerAsPerson = d->organizerAsPerson();
+    const KCalCore::Person organizerAsPerson = d->organizerAsPerson();
 #ifdef KDEPIM_ENTERPRISE_BUILD
     incidence->addAttendee(d->organizerAsAttendee(organizerAsPerson));
 #endif
-    for (const KCalCore::Attendee::Ptr &attendee : qAsConst(d->mAttendees)) {
+    for (const KCalCore::Attendee &attendee : qAsConst(d->mAttendees)) {
         incidence->addAttendee(attendee);
     }
     // Ical standard: No attendees -> must not have an organizer!
@@ -388,7 +383,7 @@ void IncidenceDefaults::setDefaults(const KCalCore::Incidence::Ptr &incidence) c
         incidence->setOrganizer(organizerAsPerson);
     }
 
-    for (const KCalCore::Attachment::Ptr &attachment : qAsConst(d->mAttachments)) {
+    for (const KCalCore::Attachment &attachment : qAsConst(d->mAttachments)) {
         incidence->addAttachment(attachment);
     }
 
