@@ -580,12 +580,12 @@ void IncidenceDialogPrivate::load(const Akonadi::Item &item)
 
     const KCalCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
     const QStringList allEmails = IncidenceEditorNG::EditorConfig::instance()->allEmails();
-    KCalCore::Attendee::Ptr me = incidence->attendeeByMails(allEmails);
+    const KCalCore::Attendee me = incidence->attendeeByMails(allEmails);
 
     if (incidence->attendeeCount() > 1     // >1 because you won't drink alone
-        && me && (me->status() == KCalCore::Attendee::NeedsAction
-                  || me->status() == KCalCore::Attendee::Tentative
-                  || me->status() == KCalCore::Attendee::InProcess)) {
+        && !me.isNull() && (me.status() == KCalCore::Attendee::NeedsAction
+                  || me.status() == KCalCore::Attendee::Tentative
+                  || me.status() == KCalCore::Attendee::InProcess)) {
         // Show the invitation bar: "You are invited [accept] [decline]"
         mUi->mInvitationBar->show();
     } else {
@@ -645,9 +645,6 @@ Akonadi::Item IncidenceDialogPrivate::save(const Akonadi::Item &item)
     mEditor->save(newIncidence);
     mEditor->save(result);
 
-    // TODO: Remove this once we support moving of events/todo's
-    mCalSelector->setEnabled(false);
-
     // Make sure that we don't loose uid for existing incidence
     newIncidence->setUid(mEditor->incidence<KCalCore::Incidence>()->uid());
 
@@ -761,8 +758,6 @@ void IncidenceDialog::load(const Akonadi::Item &item, const QDate &activeDate)
     d->mIeDateTime->setActiveDate(activeDate);
     if (item.isValid()) {   // We're editing
         d->mItemManager->load(item);
-        // TODO: Remove this once we support moving of events/todo's
-        d->mCalSelector->setEnabled(false);
     } else { // We're creating
         Q_ASSERT(d->hasSupportedPayload(item));
         d->load(item);
