@@ -46,19 +46,16 @@ public:
         NoUpdate,       /**< do not send mail to attendee */
         Edit            /**< open composer for attendee */
     };
-    explicit IndividualMailDialog(const QString &question,
-                                  const KCalCore::Attendee::List &attendees,
-                                  const KGuiItem &buttonYes, const KGuiItem &buttonNo,
-                                  QWidget *parent = nullptr);
+    explicit IndividualMailDialog(const QString &question, const KCalCore::Attendee::List &attendees, const KGuiItem &buttonYes, const KGuiItem &buttonNo, QWidget *parent = nullptr);
     ~IndividualMailDialog() override;
 
-    KCalCore::Attendee::List editAttendees() const;
-    KCalCore::Attendee::List updateAttendees() const;
+    Q_REQUIRED_RESULT KCalCore::Attendee::List editAttendees() const;
+    Q_REQUIRED_RESULT KCalCore::Attendee::List updateAttendees() const;
 
 private:
     void updateButtonState();
 
-    QHash<KCalCore::Attendee::Ptr, QComboBox *> mAttendeeDecision;
+    std::vector<std::pair<KCalCore::Attendee, QComboBox*>> mAttendeeDecision;
     QDialogButtonBox *m_buttons = nullptr;
     QWidget *m_detailsWidget = nullptr;
 };
